summaryrefslogtreecommitdiff
path: root/chromium/chrome/browser/ui/webui/chromeos/login/gaia_screen_handler.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/chrome/browser/ui/webui/chromeos/login/gaia_screen_handler.h')
-rw-r--r--chromium/chrome/browser/ui/webui/chromeos/login/gaia_screen_handler.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/chromium/chrome/browser/ui/webui/chromeos/login/gaia_screen_handler.h b/chromium/chrome/browser/ui/webui/chromeos/login/gaia_screen_handler.h
index 2cda506da93..5ef51ba2f57 100644
--- a/chromium/chrome/browser/ui/webui/chromeos/login/gaia_screen_handler.h
+++ b/chromium/chrome/browser/ui/webui/chromeos/login/gaia_screen_handler.h
@@ -58,9 +58,11 @@ class GaiaScreenHandler : public BaseScreenHandler,
void LoadGaia(const GaiaContext& context);
- // Callback that loads GAIA after version information has been retrieved.
- void LoadGaiaWithVersion(const GaiaContext& context,
- const std::string& platform_version);
+ // Callback that loads GAIA after version and stat consent information has
+ // been retrieved.
+ void LoadGaiaWithVersionAndConsent(const GaiaContext& context,
+ const std::string* platform_version,
+ const bool* collect_stats_consent);
// Sends request to reload Gaia. If |force_reload| is true, request
// will be sent in any case, otherwise it will be sent only when Gaia is